package com.ruoyi.system.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.system.domain.TableQrcode;

import java.util.List;

/**
 * 餐桌码Service接口
 */
public interface ITableQrcodeService extends IService<TableQrcode>
{
    public TableQrcode selectTableQrcodeById(Long id);

    public List<TableQrcode> selectTableQrcodeList(TableQrcode tableQrcode);

    public int insertTableQrcode(TableQrcode tableQrcode);

    public int updateTableQrcode(TableQrcode tableQrcode);

    public int deleteTableQrcodeById(Long id);

    public int checkTableNoUnique(TableQrcode tableQrcode);

    /**
     * 生成二维码Base64图片
     */
    public String generateQrcodeImage(Long id);
}
